### Name: ioprofile
### Title: Produce Individual Ordinal Time Profiles for Plotting
### Aliases: ioprofile ioprofile.default ioprofile.kalordinal
###   plot.ioprofile
### Keywords: hplot

### ** Examples

library(ordinal)

#
# Binary data
#
data(cardiac.indiv)

y <- restovec(cardiac.indiv[,1:4],type="ordinal")

cov <- tcctomat(as.matrix(cardiac.indiv[,5:10]))

w <- rmna(y,ccov=cov)

rm(cardiac.indiv,y,cov)

# Time-constant and time-varying covariate with a frailty dependence.
z <- kalord(w,distribution="binary",mu=~age+ren+cop+dia+sex+pmi+times,
            ptvc=c(4.43357,-0.03128,-0.62602,-0.37679,-0.32969,-0.17013,
                   -0.12209,-0.09095),pinit=0.1196,dep="frailty")

# Recursive mean profiles.
par(mfrow=c(2,2))
plot(ioprofile(z,"mean"),nind=1)
plot(ioprofile(z,"mean"),nind=5)
plot(ioprofile(z,"mean"),nind=c(1,5))
plot(ioprofile(z,"mean"),nind=12)
par(mfrow=c(1,1))

# Recursive highest probability profiles.
par(mfrow=c(2,2))
plot(ioprofile(z,"prob"),nind=1)
plot(ioprofile(z,"prob"),nind=5)
plot(ioprofile(z,"prob"),nind=c(1,5))
plot(ioprofile(z,"prob"),nind=12)
par(mfrow=c(1,1))

# Recursive predicted profiles.
par(mfrow=c(2,3))
plot(ioprofile(z,"both"),nind=1)
plot(ioprofile(z,"both"),nind=5)
plot(ioprofile(z,"both"),nind=12)
plot(ioprofile(z,"both"),nind=c(1,5,12),add=T)
par(mfrow=c(1,1))

# Recursive cumulative probability profiles.
par(mfrow=c(2,2))
plot(ioprofile(z,"cum"),nind=1)
plot(ioprofile(z,"cum"),nind=5)
plot(ioprofile(z,"cum"),nind=c(1,5),add=T)
par(mfrow=c(1,1))

rm(w,z)

#
# Ordinal data
#
data(tmi2)

y <- restovec(tmi2[,1:4],type="ordinal")

cov <- tcctomat(tmi2[,5],name="distance")

w <- rmna(y,ccov=cov)

rm(tmi2,y,cov)

# Proportional-odds model with time-constant covariate with a Markov dependence.
z <- kalord(w,distribution="proportional-odds",ccov=~distance,
            preg=c(-1.89,11.652,-0.199),pinit=3.111,pdep=0.217,dep="Markov")

# Recursive mean profiles.
par(mfrow=c(2,2))
plot(ioprofile(z,"mean"),nind=1)
plot(ioprofile(z,"mean"),nind=268)
plot(ioprofile(z,"mean"),nind=c(1,268))
plot(ioprofile(z,"mean"),nind=117)
par(mfrow=c(1,1))

# Recursive highest probability profiles.
par(mfrow=c(2,2))
plot(ioprofile(z,"prob"),nind=1)
plot(ioprofile(z,"prob"),nind=268)
plot(ioprofile(z,"prob"),nind=c(1,268))
plot(ioprofile(z,"prob"),nind=117)
par(mfrow=c(1,1))

# Recursive predicted profiles.
par(mfrow=c(2,2))
plot(ioprofile(z,"both"),nind=120)
plot(ioprofile(z,"both"),nind=268)
plot(ioprofile(z,"both"),nind=c(1,117),add=T)
par(mfrow=c(1,1))

# Recursive cumulative probability profiles.
par(mfrow=c(2,2))
plot(ioprofile(z,"cum"),nind=1)
plot(ioprofile(z,"cum"),nind=268)
plot(ioprofile(z,"cum"),nind=c(117,120),add=T)
par(mfrow=c(1,1))

rm(w,z)



